const Deploy = require('../deploy');
const render = require('../output');
const util = require('util');
var inquirer = require('inquirer');
const exec = util.promisify(require('child_process').exec);

class DeployCraft extends Deploy {
  constructor(props, installedPath) {
    super();
    this.props = props;
    this.props.webroot = 'web';
    this.installedPath = installedPath;

    this.dependencies = [
      'craftcms/redactor',
      'customd/healthz',
      'yiisoft/yii2-redis',
      'craftcms/aws-s3',
      'clubstudioltd/craft-asset-rev',
      'panlatent/schedule',
      'nystudio107/craft-seomatic',
      'verbb/super-table',
      'misterbk/mix',
    ];

    this.devDependencies = [];

    this.extras = [];
    this.commands = [];

    if (this.props.siteRepo === '') {
      this.props.siteRepo = 'craftcms/craft';
    }
  }

  async checkHeadless() {
    const {headless} = await inquirer.prompt({
      type: 'confirm',
      name: 'headless',
      message: 'Use Headless mode',
      default: true,
    });

    this.props.headless = headless;
  }

  async deployCraft() {
    await this.checkSiteName();
    await this.getSitesPath();
    await this.checkHeadless();
    await this.checkSiteFolderStatus();

    await this.composeCraft();

    render.arrow(`Inititalising`);
    await this.runProcess('fin', ['setup'], {cwd: this.props.sitePath});
  }

  async composeCraft() {
    render.arrow(`Installing Craft to ${this.props.sitePath}`);

    await this.createDocksalProjectFolder();

    //irritatinly locked to php 7.2 ????
    await this.runProcess('sed', ['-i', '', 's:"php".*: :g', 'composer.json'], {cwd: this.props.sitePath});

    render.arrow(`Customising Craft Plugins`);
    await this.addComposerDependancies(this.dependencies);

    render.arrow(`updating Craft .env variables`);

    await this.runProcess('sed', ['-i', '', 's:CRAFT_DB_SERVER=.*:CRAFT_DB_SERVER="db":g', '.env'], {
      cwd: this.props.sitePath,
    });
    await this.runProcess('sed', ['-i', '', 's:CRAFT_DB_USER=.*:CRAFT_DB_USER="user":g', '.env'], {
      cwd: this.props.sitePath,
    });
    await this.runProcess('sed', ['-i', '', 's:CRAFT_DB_PASSWORD=.*:CRAFT_DB_PASSWORD="user":g', '.env'], {
      cwd: this.props.sitePath,
    });
    await this.runProcess('sed', ['-i', '', 's:CRAFT_DB_DATABASE=.*:CRAFT_DB_DATABASE="default":g', '.env'], {
      cwd: this.props.sitePath,
    });
    await this.runProcess('sed', ['-i', '', 's:CRAFT_DB_SERVER=.*:CRAFT_DB_SERVER="db":g', '.env.example'], {
      cwd: this.props.sitePath,
    });
    await this.runProcess('sed', ['-i', '', 's:CRAFT_DB_USER=.*:CRAFT_DB_USER="user":g', '.env.example'], {
      cwd: this.props.sitePath,
    });
    await this.runProcess('sed', ['-i', '', 's:CRAFT_DB_PASSWORD=.*:CRAFT_DB_PASSWORD="user":g', '.env.example'], {
      cwd: this.props.sitePath,
    });
    await this.runProcess('sed', ['-i', '', 's:CRAFT_DB_DATABASE=.*:CRAFT_DB_DATABASE="default":g', '.env.example'], {
      cwd: this.props.sitePath,
    });
    // await this.runCliCommand(['sed', '-i', 's:CRAFT_DB_SERVER=.*:CRAFT_DB_SERVER="db":g', '.env']);
    // await this.runCliCommand(['sed', '-i', 's:CRAFT_DB_USER=.*:CRAFT_DB_USER="user":g', '.env']);
    // await this.runCliCommand(['sed', '-i', 's:CRAFT_DB_PASSWORD=.*:CRAFT_DB_PASSWORD="user":g', '.env']);
    // await this.runCliCommand(['sed', '-i', 's:CRAFT_DB_DATABASE=.*:CRAFT_DB_DATABASE="default":g', '.env']);
    // await this.runCliCommand(['sed', '-i', 's:CRAFT_DB_SERVER=.*:CRAFT_DB_SERVER="db":g', '.env.example']);
    // await this.runCliCommand(['sed', '-i', 's:CRAFT_DB_USER=.*:CRAFT_DB_USER="user":g', '.env.example']);
    // await this.runCliCommand(['sed', '-i', 's:CRAFT_DB_PASSWORD=.*:CRAFT_DB_PASSWORD="user":g', '.env.example']);
    // await this.runCliCommand(['sed', '-i', 's:CRAFT_DB_DATABASE=.*:CRAFT_DB_DATABASE="default":g', '.env.example']);

    await this.runProcess(
      'sed',
      [
        '-i',
        '',
        "s:'->disallowRobots(!$isProd),:'disallowRobots' => !$isProd,\\n'->runQueueAutomatically($isDev)->errorTemplatePrefix('_'):g",
        'config/general.php',
      ],
      {cwd: this.props.sitePath}
    );

    await exec(`echo REDIS_HOST=redis >> ${this.props.sitePath}/.env`);
    await exec(`echo AWS_ACCESS_KEY_ID= >> ${this.props.sitePath}/.env`);
    await exec(`echo AWS_SECRET_ACCESS_KEY= >> ${this.props.sitePath}/.env`);
    await exec(`echo AWS_BUCKET= >> ${this.props.sitePath}/.env`);
    await exec(`echo AWS_DEFAULT_REGION= >> ${this.props.sitePath}/.env`);

    await exec(`echo REDIS_HOST=redis >> ${this.props.sitePath}/.env.example`);
    await exec(`echo AWS_ACCESS_KEY_ID= >> ${this.props.sitePath}/.env.example`);
    await exec(`echo AWS_SECRET_ACCESS_KEY= >> ${this.props.sitePath}/.env.example`);
    await exec(`echo AWS_BUCKET= >> ${this.props.sitePath}/.env.example`);
    await exec(`echo AWS_DEFAULT_REGION= >> ${this.props.sitePath}/.env.example`);

    await exec(`cp -rf ${this.installedPath}/stubs/craft/. ${this.props.sitePath}`);

    await this.setupCraftFrontend();
  }

  async setupCraftFrontend() {
    if (this.props.headless) {
      return;
    }
    await this.runProcess('yarn', ['add', 'laravel-mix', 'cross-env', 'materialize-css@next'], {cwd: this.props.sitePath});
  }
}

module.exports = DeployCraft;
