var inquirer = require('inquirer');
const util = require('util');
const render = require('../output');

async function addAuth() {
  const {authEngine} = await inquirer.prompt({
    type: 'list',
    name: 'authEngine',
    message: 'Select Auth Engine',
    choices: [
      {
        value: 'none',
        name: 'None - No auth required in the project / will do it myself',
      },
      {
        value: 'breeze',
        name: 'SUGGESTED - Breeze Api stack with Sanctum - Provides stateful auth for Single Page Apps, where the SPA will provide auth UI',
      },
      {
        value: 'sanctum',
        name: 'Sanctum - Provides stateful auth for Single Page Apps, where the SPA will provide auth UI',
      },
      {
        value: 'jetstream',
        name:
          'Jetstream - Provides stateful auth using Laravel Fortify, and a UI starter kit based on Vue.js or Blade templates, both of which include fully functional Auth layouts',
      },
      {
        value: 'fortify',
        name: 'Fortify - Provides only the backend code for basic user auth, you will need to inject all views',
      },
      {
        value: 'passport',
        name: 'Passport - Provide secure auth for third parties, or for Mobile Apps',
      },
    ],
    default: 1,
  });

  if (authEngine === 'fortify') {
    this.dependencies.push('laravel/fortify');
  }

  if (authEngine === 'jetstream') {
    this.dependencies.push('laravel/jetstream');
  }

  if (authEngine === 'sanctum') {
    this.dependencies.push('laravel/sanctum', 'laravel/fortify');
  }

  if (authEngine === 'passport') {
    this.dependencies.push('laravel/passport', 'laravel/fortify');
  }

  if (authEngine === 'breeze') {
    this.dependencies.push('laravel/breeze');
  }

  if (authEngine !== 'none') {
    this.extras.push(authEngine);
  }
}

module.exports = addAuth;
