import React, {useState} from 'react';

import {render, fireEvent} from '@utils/testing';

import Button from '@mui/material/Button';
import Example from './Example';

const Template = args => {
  const [open, setOpen] = useState(false);

  const toggleDialog = () => {
    setOpen(prev => !prev);
  };

  return (
    <div>
      <Button onClick={toggleDialog}>Open Dialog</Button>
      <Example
        // eslint-disable-next-line react/jsx-props-no-spreading
        {...args}
        open={open}
        onClose={toggleDialog}
      />
    </div>
  );
};

const Actions = () => (
  <>
    <Button variant="text" size="small">
      Cancel
    </Button>
    <Button variant="text" size="small">
      Action
    </Button>
  </>
);

const props = {
  title: 'this is a dialog',
  children:
    'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.',
  actions: <Actions />,
};

test("doesn't crash", () => {
  render(
    <Template
      // eslint-disable-next-line react/jsx-props-no-spreading
      {...props}
    />
  );
});

test('modal shows title, children and actions', () => {
  // Arrange
  const handleClose = jest.fn();

  // Act
  const {getByText} = render(
    <Example
      title="this is a dialog"
      open
      onClose={handleClose}
      actions={
        <>
          <Button variant="text" size="small" onClick={handleClose}>
            Cancel
          </Button>
          <Button variant="text" size="small">
            Action
          </Button>
        </>
      }>
      Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis
      nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.
    </Example>
  );
  // Assert
  expect(getByText('this is a dialog')).toBeTruthy();
  expect(getByText(/Lorem ipsum dolor sit amet/i)).toBeTruthy();

  // Act
  fireEvent.click(getByText(/Cancel/i));

  // Assert
  expect(handleClose).toHaveBeenCalledTimes(1);
});
