import React from 'react';
import PropTypes from 'prop-types';
import {CacheProvider} from '@emotion/react';

import {ThemeProvider, createEmotionCache} from '@theme';

const clientSideEmotionCache = createEmotionCache();

const App = ({Component, pageProps, emotionCache}) => (
  <CacheProvider value={emotionCache}>
    <ThemeProvider>
      <Component
        // eslint-disable-next-line react/jsx-props-no-spreading
        {...pageProps}
      />
    </ThemeProvider>
  </CacheProvider>
);

App.propTypes = {
  Component: PropTypes.elementType.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  pageProps: PropTypes.object.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  emotionCache: PropTypes.object,
};

App.defaultProps = {
  emotionCache: clientSideEmotionCache,
};

export default App;
